@@ -308,7 +308,7 @@ confirm_overwrite_existing_file (GFile *uri, int *overwrite_mode, goffset info_s
                                    GTK_BUTTONS_NONE,
                                    _("A file with the same name exists"));
   gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                            _("A file called '%s' exists, size %s.\nDo you want to skip this track or overwrite it?"),
+                                            _("A file called ‘%s’ exists, size %s.\nDo you want to skip this track or overwrite it?"),
                                             display_name, size);
   g_free (display_name);
   g_free (size);
@@ -1168,14 +1168,15 @@ filepath_parse_pattern (const char* pattern, const TrackDetails *track)
       case 'N':
         /* Disc and track number, zero padded */
         if (track->album->disc_number > 0) {
-          const gchar *format;
+          int width;
+
           if (track->album->disc_count < 10)
-            format = "d%dt%02d";
+            width = 1;
           else if (track->album->disc_count < 100)
-            format = "d%02dt%02d";
+            width = 2;
           else
-            format = "d%03dt%02d";
-          string = g_strdup_printf (format, track->album->disc_number, track->number);
+            width = 3;
+          string = g_strdup_printf ("d%0*dt%02d", width, track->album->disc_number, track->number);
         } else {
           string = g_strdup_printf ("%02d", track->number);
         }
